@@ -6,7 +6,7 @@ import github.PullRequest
 import github.Repository
 import structlog
 
-from .source import PullRequest, Repository, SourceLister
+from .source import Base, PullRequest, Repository
 
 log = structlog.get_logger(source="github")
 
@@ -38,14 +38,25 @@ class GithubRepository(Repository):
             maintainer_can_modify=True,
         )
 
-    def find_open_pull_request(self, branch: str) -> Union[Any, None]:
+    def find_pull_request(self, branch: str) -> Union[Any, None]:
         log.debug("Listing pull requests", repo=str(self))
-        for pr in self.repo.get_pulls(state="open"):
+        for pr in self.repo.get_pulls(state="all"):
             if pr.head.ref == branch:
                 return pr
 
         return None
 
+    def has_file(self, path: str) -> bool:
+        try:
+            self.repo.get_contents(path=path, ref=self.base_branch)
+        except github.UnknownObjectException as e:
+            if e.status == 404:
+                return False
+            else:
+                raise e
+
+        return True
+
     def has_successful_pr_build(self, pr: github.PullRequest.PullRequest) -> bool:
         log.debug("Checking PR builds", repo=str(self))
         for cr in self.repo.get_commit(pr.head.sha).get_check_runs():
@@ -60,6 +71,15 @@ class GithubRepository(Repository):
 
         return True
 
+    def is_pr_closed(self, pr: github.PullRequest.PullRequest) -> bool:
+        return pr.state == "closed" and pr.merged is False
+
+    def is_pr_merged(self, pr: github.PullRequest.PullRequest) -> bool:
+        return pr.state == "closed" and pr.merged is True
+
+    def is_pr_open(self, pr: github.PullRequest.PullRequest) -> bool:
+        return pr.state == "open"
+
     def merge_pull_request(self, pr: github.PullRequest.PullRequest):
         if pr.mergeable:
             log.debug("Merging pull request", repo=str(self))
@@ -87,9 +107,9 @@ class GithubRepository(Repository):
         return "github.com"
 
 
-class Github(SourceLister):
-    def __init__(self, access_token):
-        self.client = github.Github(access_token)
+class Github(Base):
+    def __init__(self, access_token: str, base_url: str):
+        self.client = github.Github(login_or_token=access_token, base_url=base_url)
 
     def list_repositories(self) -> list[Repository]:
         log.debug("start fetching repositories")
